/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-11-13 16:34:46.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.api.controller;

import cn.com.qmth.examcloud.commons.web.support.ControllerSupport;
import cn.com.qmth.examcloud.core.print.common.Result;
import cn.com.qmth.examcloud.core.print.service.CoursePaperService;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.CoursePaperForm;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.CoursePaperInfo;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.CoursePaperQuery;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.CoursePaperTotalInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.io.File;
import java.util.List;

import static cn.com.qmth.examcloud.core.print.common.Result.success;

/**
 * 课程试卷相关接口
 *
 * @author: fengdesheng
 * @since: 2018/11/13
 */
@RestController
@Api(tags = "课程试卷相关接口")
@RequestMapping("${$rmp.ctrl.print}/course/paper")
public class CoursePaperController extends ControllerSupport {
    @Autowired
    private CoursePaperService coursePaperService;

    @PostMapping("/list")
    @ApiOperation(value = "获取课程试卷列表")
    public List<CoursePaperInfo> list(@RequestBody CoursePaperQuery query) {
        return coursePaperService.getCoursePaperList(query);
    }

    @PostMapping("/save")
    @ApiOperation(value = "保存课程试卷")
    public Result saveCoursePaper(@RequestBody CoursePaperForm form) {
        //coursePaperService.saveCoursePaper(form);
        return success();
    }

    @PostMapping("/allot/{courseStatisticId}/{coursePaperId}")
    @ApiOperation(value = "(单个)分配待指定试卷")
    public Result allotCoursePaper(@PathVariable Long courseStatisticId, @PathVariable Long coursePaperId) {
        coursePaperService.allotCoursePaper(courseStatisticId, coursePaperId);
        return success();
    }

    @PostMapping("/allot/all/{orgId}/{examId}")
    @ApiOperation(value = "(整体)分配待指定试卷")
    public Result allotAllCoursePaper(@PathVariable Long orgId, @PathVariable Long examId) {
        coursePaperService.allotAllCoursePaper(orgId, examId);
        return success();
    }

    @PostMapping("/total/{orgId}/{examId}")
    @ApiOperation(value = "获取某学校考试的试卷数量情况")
    public CoursePaperTotalInfo paperTotal(@PathVariable Long orgId, @PathVariable Long examId) {
        return coursePaperService.getPaperTotalByOrgIdAndExamId(orgId, examId);
    }

    @GetMapping("/export/all/{orgId}/{examId}")
    @ApiOperation(value = "整体导出(导出考试下所有试卷文件)")
    public void exportAll(@PathVariable Long orgId, @PathVariable Long examId) throws Exception {
        File file = coursePaperService.exportAllByOrgIdAndExamId(orgId, examId);
        final String fileName = "structures.zip";
        //super.exportFile(fileName, file);//todo
        super.exportFile(fileName, new byte[]{});
    }

    @GetMapping("/export/batch/{ids}")
    @ApiOperation(value = "批量导出")
    public void exportBatch(@PathVariable Long[] ids) throws Exception {
        File file = coursePaperService.exportBatchByIds(ids);
        final String fileName = "papers.zip";
        //super.exportFile(fileName, file);//todo
        super.exportFile(fileName, new byte[]{});
    }

    /**
     * 下载考试结构
     */
    @GetMapping("/download/structure/{examId}/{paperId}")
    @ApiOperation(value = "下载考试结构")
    public void downloadPaperStructure(@PathVariable Long examId, @PathVariable Long paperId) throws Exception {
        File file = coursePaperService.downloadPaperStructure(examId, paperId);
        final String fileName = "paper.zip";
        //super.exportFile(fileName, file);//todo
        super.exportFile(fileName, new byte[]{});
    }

    /**
     * 校验考试结构
     */
    @PostMapping("/check/structure/{examId}/{paperId}")
    @ApiOperation(value = "校验考试结构")
    public Result checkPaperStructure(@PathVariable Long examId, @PathVariable Long paperId) {
        coursePaperService.checkPaperStructure(examId, paperId);
        return success();
    }

}